@echo off
@REM ##########################################################################
@REM # Licensed Materials - Property of IBM
@REM # 5724-D33
@REM # IBM Tivoli License Manager
@REM #
@REM # (C) Copyright IBM Corp. 2004.  All Rights Reserved.
@REM #
@REM # US Government Users Restricted Rights - Use, duplication or
@REM # disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
@REM ##########################################################################

@REM ##########################################################################
@REM File       : tlminstall.bat
@REM Purpose    : Deploy the TLM Agent through Domain Logon.
@REM Parameter1 : base path for agent installation dir
@REM Parameter2 : the directory for the log file (optional)
@REM ##########################################################################

rem ***************************************************************************
rem * TLM Agent Install configuration 
rem ***************************************************************************

rem ***************************************************************************
rem * TLM_BASEPATH_DIR is the base path for the agent installation 
rem * directory and the profiles directory on the PDC machine. 
rem ***************************************************************************
set TLM_BASEPATH_DIR=%1
set TLM_LOGS_DIR=%2

rem ***************************************************************************
rem * TLM_PROFILES_DIR is the directory which contains the profile files.
rem ***************************************************************************
set TLM_PROFILES_DIR=%TLM_BASEPATH_DIR%\profiles

if "%TLM_LOGS_DIR%"=="nul" set LOG_FILE=nul
if not "%TLM_LOGS_DIR%"=="nul" set LOG_FILE=%TLM_LOGS_DIR%\default.log

rem Where the TLM agent is installed (if it is)
SET TLM_INSTALLED_DIR=%windir%\itlm


rem Retrieve the hostname
rem Removing old files..
if exist %TEMP%\gethost.exe del %TEMP%\gethost.exe >nul
if exist %TEMP%\sethostname.bat del %TEMP%\sethostname.bat >nul
if exist %TEMP%\setAgentReturnCode.bat del %TEMP%\setAgentReturnCode.bat >nul
if exist %TEMP%\printmsg.exe del %TEMP%\printmsg.exe >nul


rem Copy new files...
if exist %TLM_BASEPATH_DIR%\gethost.exe copy %TLM_BASEPATH_DIR%\gethost.exe %TEMP% >nul
if exist %TLM_BASEPATH_DIR%\sethostname.bat copy %TLM_BASEPATH_DIR%\sethostname.bat %TEMP% >nul
if exist %TLM_BASEPATH_DIR%\setAgentReturnCode.bat copy %TLM_BASEPATH_DIR%\setAgentReturnCode.bat %TEMP% >nul
if exist %TLM_BASEPATH_DIR%\getdt.exe copy %TLM_BASEPATH_DIR%\getdt.exe %TEMP% >nul
if exist %TLM_BASEPATH_DIR%\printmsg.exe copy %TLM_BASEPATH_DIR%\printmsg.exe %TEMP% >nul

%TEMP%\gethost >> %TEMP%\sethostname.bat
call %TEMP%\sethostname.bat
if %HOSTNAME%==nul goto nameerror


rem Defining the conf file name
if not exist  %TLM_PROFILES_DIR%\%HOSTNAME%.conf set CONF_FILE_NAME=default.conf
if exist %TLM_PROFILES_DIR%\%HOSTNAME%.conf set CONF_FILE_NAME=%HOSTNAME%.conf

rem Defining log file name
if not %TLM_LOGS_DIR%==nul set LOG_FILE=%TLM_LOGS_DIR%\%HOSTNAME%.log
if not %TLM_LOGS_DIR%==nul set DEPLOY_LOG_FILE=%TLM_LOGS_DIR%\trace_agt_win_deploy%HOSTNAME%.log

if %TLM_LOGS_DIR%==nul goto nodellog

rem Removing old log file
if exist %LOG_FILE% del %LOG_FILE% >nul
if exist %DEPLOY_LOG_FILE% del %DEPLOY_LOG_FILE% >nul
:nodellog

echo TLM AGENT DEPLOYMENT LOG FILE >> %LOG_FILE% 
%TEMP%\getdt >> %LOG_FILE%
echo. >> %LOG_FILE%


rem ***************************************************************************
rem * Trace useful env vars, and techniques gather info for (*)
rem ***************************************************************************

echo Some useful info: >> %LOG_FILE%
echo TLM base installer path=%TLM_BASEPATH_DIR% >> %LOG_FILE%
echo TLM profiles dir=%TLM_PROFILES_DIR% >>%LOG_FILE%
echo TLM agent Logon script path=%TLM_BASEPATH_DIR% >> %LOG_FILE%
echo TLM agent installation dir=%TLM_BASEPATH_DIR% >> %LOG_FILE%
echo Agent Configuration file=%CONF_FILE_NAME% >> %LOG_FILE%
echo Home drive = %HOMEDRIVE% >> %LOG_FILE%
echo Home share = %HOMESHARE% >> %LOG_FILE%
echo Windows directory = %windir% >> %LOG_FILE%
echo OperatingSystem = %OS% >> %LOG_FILE%
echo Hostname = %HOSTNAME% >> %LOG_FILE%
echo Username = %USERNAME% >> %LOG_FILE%
echo Userdomain = %USERDOMAIN% >> %LOG_FILE%
echo Processor = %PROCESSOR_ARCHITECTURE% (Level=%PROCESSOR_LEVEL%) >> %LOG_FILE%
echo Temporary dir = %TEMP%  >> %LOG_FILE%
echo Logfile = %LOG_FILE% >> %LOG_FILE%
echo DeploymentLogFile = %DEPLOY_LOG_FILE% >> %LOG_FILE%

rem ***************************************************************************
rem * Checking Agent Istalled and Agent Installer
rem ***************************************************************************

rem If TLM agent not installed ... install it
if not exist %TLM_INSTALLED_DIR%\tlmagent.exe goto newagent

rem Spurious clean up 
if exist %TEMP%\TLMinstalled.ver del %TEMP%\TLMinstalled.ver
if exist %TEMP%\TLMinstaller.ver del %TEMP%\TLMinstaller.ver

rem Get installed version
%TLM_INSTALLED_DIR%\tlmagent.exe -v > %TEMP%\TLMinstalled.ver

rem Get installer version
%TLM_BASEPATH_DIR%\tlmagent.exe -v > %TEMP%\TLMinstaller.ver

rem If they differ update agent
fc %TEMP%\TLMinstalled.ver %TEMP%\TLMinstaller.ver  > nul
if ERRORLEVEL 1 goto updateagent
goto agentok

:updateagent
echo Updating TLM Agent... >> %LOG_FILE%
goto installagent

:newagent
echo Installing TLM Agent... >> %LOG_FILE%
goto installagent

rem ***************************************************************************
rem * Current TLM agent install
rem ***************************************************************************
:installagent

echo installing the agent through the ismp silent installation >> %LOG_FILE%
call %TLM_BASEPATH_DIR%\Win32\setupManualDeployAgent.exe -options "%TLM_PROFILES_DIR%\%CONF_FILE_NAME%" -silent > nul
set installResult=%errorlevel%
echo ismp installation completed with result %installResult% >> %LOG_FILE%

rem  COPYING THE LOG FILE
if exist %TEMP%\trace_agt_manual_deploy.log copy  %TEMP%\trace_agt_manual_deploy.log  %DEPLOY_LOG_FILE% >nul

rem check the file slmrc to parse the result of the agent installation
if exist %TEMP%\manualDeploy\tmp_dir\slmrc goto checkReturnCode

goto ismpInstallerror

:checkReturnCode
TYPE %TEMP%\manualDeploy\tmp_dir\slmrc >> %TEMP%\setAgentReturnCode.bat
call %TEMP%\setAgentReturnCode.bat
if %returnCode%==nul goto ismpInstallerror


echo Agent installation return code: %returnCode%  >> %LOG_FILE%
if %returnCode% == 0 goto installsucceded
goto installerror

:installsucceded
echo Agent installation succesfully completed
echo Agent installation parameters: >> %LOG_FILE%
type %TLM_INSTALLED_DIR%\tlmagent.ini >> %LOG_FILE%
goto end


:nameerror
echo ***ERROR***: Couldn't retrieve hostname >> %LOG_FILE%
goto end

:error
echo ***ERROR*** >> %LOG_FILE%
goto end

:agentok
echo TLM Agent up to date. No upgrade needed. >> %LOG_FILE%
goto end


:ismpInstallerror
echo ***INSTALL ERROR*** An Error occurred when trying to deploy the agent, see trace_agt_manual_deploy%HOSTNAME%.log for more details   >> %LOG_FILE%
goto end

:installerror
echo ***INSTALL ERROR*** occurred during installagent execution >> %LOG_FILE%
if %returnCode% == 30 goto displaymessage
 
goto end

:displaymessage
call %TEMP%\printmsg.exe
goto end

:uninstallerror
echo ***UNINSTALL ERROR*** Error during the installagent uninstall >> %LOG_FILE%

:end
rem Deleting temporary files..

if exist %TEMP%\TLMinstalled.ver del %TEMP%\TLMinstalled.ver >nul
if exist %TEMP%\TLMinstaller.ver del %TEMP%\TLMinstaller.ver >nul
if exist %TEMP%\default.conf del %TEMP%\default.conf >nul
if exist %TEMP%\%HOSTNAME%.conf del %TEMP%\%HOSTNAME%.conf >nul
if exist %TEMP%\gethost.exe del %TEMP%\gethost.exe >nul
if exist %TEMP%\getdt.exe del %TEMP%\getdt.exe >nul
if exist %TEMP%\sethostname.bat del %TEMP%\sethostname.bat >nul
if exist %TEMP%\printmsg.exe  del %TEMP%\printmsg.exe >nul
if exist %TEMP%\setAgentReturnCode.bat del %TEMP%\setAgentReturnCode.bat >nul







